#
# spec file for package pam_kwallet6
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.10.0
%define qt6_version 6.7.0

%define rname kwallet-pam

%bcond_without released
Name:           pam_kwallet6
Version:        6.3.5
Release:        2.1
Summary:        A PAM Module for KWallet signing
License:        GPL-2.0-or-later AND LGPL-2.1-only AND GPL-3.0-only
URL:            https://www.kde.org/
Source:         https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
Source3:        baselibs.conf
# PATCH-FEATURE-OPENSUSE
Patch0:         0002-Use-GNUInstallDirs-instead-of-KDEInstallDirs.patch
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  socat
BuildRequires:  pkgconfig(libgcrypt) >= 1.5.0
# PAM modules need to be available for all archs of PAM on the system, otherwise pam-config
# will not enable it.
# Technically there can be different suffixes than just -32bit, but that's the most common.
# Expressing a hard dependency the other way around in baselibs.conf is not possible.
Requires:       (%{name}-32bit if pam-32bit)
Requires:       pam_kwallet6-common = %{version}
Requires(post): coreutils
Requires(post): pam
Requires(post): pam-config
Requires(postun): coreutils
Requires(postun): pam
Requires(postun): pam-config
Provides:       pam_kwallet = %{version}
Obsoletes:      pam_kwallet < %{version}

%description
This PAM module allows you to automatically open your kwallet
when signing into your account.

%package common
Summary:        Support files for the KWallet PAM module
Requires:       kwalletd6 >= 6.14.0
Requires:       socat
Provides:       pam_kwallet-common = %{version}
Obsoletes:      pam_kwallet-common < %{version}
BuildArch:      noarch

%description common
This package contains support files used by the KWallet PAM
module.

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
# While there is still kwalletd6, only ksecretd supports --pam-login
# Before usrmerge, the PAM module goes into /lib*/security/
%cmake_kf6 -DKWALLETD_BIN_PATH=%{_kf6_bindir}/ksecretd \
    -DCMAKE_INSTALL_LIBEXECDIR=%{_libexecdir} \
%if 0%{?suse_version} < 1550
    -DCMAKE_INSTALL_LIBDIR=/%{_lib}
%endif

%kf6_build

%install
%kf6_install

# Try to enable it in %post already, but it might not work at this time.
# Due to boo#728586 it is necessary to duplicate this in the 32bit variant,
# so you need to edit baselibs.conf if you change this.
%post
%{_sbindir}/pam-config -a --kwallet5 || :

%postun
if [ "$1" = "0" ]; then
  %{_sbindir}/pam-config -d --kwallet5 || :
fi

# Enable this in posttrans to win over the old package's %postun
# and to run once the modules are installed for all archs (boo#728586).
%posttrans
%{_sbindir}/pam-config -a --kwallet5 || :

%post common
%{systemd_user_post plasma-kwallet-pam.service}

%preun common
%{systemd_user_preun plasma-kwallet-pam.service}

%postun common
%{systemd_user_postun plasma-kwallet-pam.service}

%files
%license LICENSES/*
# Yes, it's still called pam_kwallet5. Not sure whether that's intentional,
# but it means PAM config doesn't need migration which is nice.
%if 0%{?suse_version} >= 1550
%{_pam_moduledir}/pam_kwallet5.so
%else
/%{_lib}/security/pam_kwallet5.so
%endif

%files common
%license LICENSES/*
%config %{_kf6_configdir}/autostart/pam_kwallet_init.desktop
%{_libexecdir}/pam_kwallet_init
%{_userunitdir}/plasma-kwallet-pam.service

%changelog
* Thu May 15 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Use ksecretd for compatibility with kwallet >= 6.14.0
* Tue May  6 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.5
- Changes since 6.3.4:
  * update version for new release
* Wed Apr  2 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.3.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/6/6.3.4
- Changes since 6.3.3:
  * update version for new release
* Tue Mar 11 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.3
- Changes since 6.3.2:
  * update version for new release
* Tue Feb 25 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.2
- Changes since 6.3.1:
  * update version for new release
* Tue Feb 18 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.1
- Changes since 6.3.0:
  * update version for new release
* Thu Feb  6 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.0
- Changes since 6.2.91:
  * update version for new release
* Thu Jan 23 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.91:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.91
- Changes since 6.2.90:
  * update version for new release
* Sat Jan 11 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.2.90
- Changes since 6.2.5:
  * update version for new release
  * Use ECMDeprecationSettings directly
  * update version for new release
* Tue Dec 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.5
- Changes since 6.2.4:
  * update version for new release
* Tue Nov 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.4
- Changes since 6.2.3:
  * update version for new release
* Tue Nov  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.3
- Changes since 6.2.2:
  * update version for new release
* Tue Oct 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.2
- Changes since 6.2.1:
  * update version for new release
* Tue Oct 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.1
- Changes since 6.2.0:
  * update version for new release
* Sat Oct  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.0
- Changes since 6.1.90:
  * update version for new release
* Tue Sep 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.1.90
- Changes since 6.1.5:
  * update version for new release
  * Fix -Wformat warning
  * Switch to pkgconfig to find libgcrypt (allows building with libgcrypt 1.11) (kde#489303)
  * update version for new release
* Tue Sep 10 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.5
- Changes since 6.1.4:
  * update version for new release
* Tue Aug  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.4
- Changes since 6.1.3:
  * update version for new release
* Tue Jul 16 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.3
- Changes since 6.1.2:
  * update version for new release
* Tue Jul  2 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.2
- Changes since 6.1.1:
  * Switch to pkgconfig to find libgcrypt (allows building with libgcrypt 1.11) (kde#489303)
  * update version for new release
* Tue Jun 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.1
- Changes since 6.1.0:
  * update version for new release
* Thu Jun 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.0
- Changes since 6.0.90:
  * update version for new release
* Sat May 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.0.90
- Changes since 6.0.5:
  * update version for new release
  * Add clang-format commit hook
  * Move cmake_minimum_required above project
  * Allow specifing KWALLETD_BIN_PATH manually
- Drop patches, now upstream:
  * 0001-Allow-specifing-KWALLETD_BIN_PATH-manually.patch
- Refresh 0002-Use-GNUInstallDirs-instead-of-KDEInstallDirs.patch
* Wed May 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.5
- Changes since 6.0.4:
  * update version for new release
* Wed Apr 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.4
- Changes since 6.0.3:
  * update version for new release
* Tue Mar 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.3
- Changes since 6.0.2:
  * update version for new release
* Thu Mar 14 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Also attempt pam-config enablement in %%posttrans (boo#1221371)
* Thu Mar 14 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Add patches to avoid depending on Qt:
  * 0001-Allow-specifing-KWALLETD_BIN_PATH-manually.patch
  * 0002-Use-GNUInstallDirs-instead-of-KDEInstallDirs.patch
* Wed Mar 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.2
- Changes since 6.0.1:
  * update version for new release
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.1
- Changes since 6.0.0:
  * update version for new release
* Mon Mar  4 2024 Christophe Marin <christophe@krop.fr>
- Add Provides/Obsoletes to replace Plasma 5
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0:
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.93.0:
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.93.0 (6.0 RC 2):
  * New bugfix release
  * See https://kde.org/announcements/megarelease/6/rc2/ for details
- No code changes since 5.92.0
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.92.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Fri Aug 25 2023 Christophe Marin <christophe@krop.fr>
- Init pam_kwallet6
